@@ -14,7 +14,7 @@ use Time::Piece ();
 has 'mysql';
 has 'no_txn' => sub { 0 };
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 sub dequeue {
   my ($self, $worker_id, $wait, $options) = @_;
@@ -106,10 +106,11 @@ sub enqueue {
   }
 
   my $db = $self->mysql->db;
-  # Use a transaction to commit the entire job at once. Without this,
-  # a job may be started before one of its parents, since the parent
-  # restriction is added after the job itself.
-  my $tx = $self->no_txn ? undef : $db->begin;
+  # If we are adding data in related tables, use a transaction to commit
+  # the entire job at once. Without this, a job may be started before
+  # one of its parents, since the parent restriction is added after the
+  # job itself.
+  my $tx = (!$insert_notes_sql && !$insert_parents_sql) || $self->no_txn ? undef : $db->begin;
 
   my $job_id = $db->query(
     "insert into minion_jobs (`args`, `attempts`, `delayed`, `expires`, `lax`, `priority`, `queue`, `task`)
@@ -780,13 +781,14 @@ sub _migrate_notes {
 #pod
 #pod =head2 no_txn
 #pod
-#pod If true, will not make a transaction around the L</enqueue> queries.
-#pod Without a transaction, a job could be dequeued before its parent
-#pod relationships are written to the database. However, since MySQL does not
-#pod support nested transactions (despite supporting something almost exactly
-#pod like them...), you can disable transactions for testing by setting this
-#pod attribute (if you perform your tests in a transaction so they can be
-#pod rolled back when the test is complete).
+#pod If true, will not make a transaction around the L</enqueue> insertions
+#pod when a job has parent jobs. Without a transaction, the job could be
+#pod dequeued before its parent relationships are written to the database.
+#pod However, since MySQL does not support nested transactions (despite
+#pod supporting something almost exactly like them...), you can disable
+#pod transactions for testing by setting this attribute (if you perform your
+#pod tests in a transaction so they can be rolled back when the test is
+#pod complete).
 #pod
 #pod =head1 METHODS
 #pod
@@ -1160,7 +1162,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -1208,13 +1210,14 @@ L<Mojo::mysql> object used to store all data.
 
 =head2 no_txn
 
-If true, will not make a transaction around the L</enqueue> queries.
-Without a transaction, a job could be dequeued before its parent
-relationships are written to the database. However, since MySQL does not
-support nested transactions (despite supporting something almost exactly
-like them...), you can disable transactions for testing by setting this
-attribute (if you perform your tests in a transaction so they can be
-rolled back when the test is complete).
+If true, will not make a transaction around the L</enqueue> insertions
+when a job has parent jobs. Without a transaction, the job could be
+dequeued before its parent relationships are written to the database.
+However, since MySQL does not support nested transactions (despite
+supporting something almost exactly like them...), you can disable
+transactions for testing by setting this attribute (if you perform your
+tests in a transaction so they can be rolled back when the test is
+complete).
 
 =head1 METHODS
 
